@@ -29,7 +29,6 @@
 #include <gtk/gtktogglebutton.h>
 
 #include "eel-preferences.h"
-#include "eel-string-list.h"
 
 #define EEL_PREFERENCES_GLADE_DATA_KEY "eel_preferences_glade_data_key"
 #define EEL_PREFERENCES_GLADE_DATA_VALUE "eel_preferences_glade_data_value"
@@ -456,11 +455,11 @@ eel_preferences_glade_list_enum_changed (GtkComboBox *combo_box,
 	int active;
 	char **values;
 	int i;
-	EelStringList *list;
+	GPtrArray *v;
 
 	widgets = g_object_get_data (G_OBJECT (combo_box), EEL_PREFERENCES_GLADE_DATA_WIDGETS);
 
-	list = eel_string_list_new (TRUE);
+	v = g_ptr_array_new ();
 	for (; widgets != NULL; widgets = widgets->next) {
 		active = gtk_combo_box_get_active (GTK_COMBO_BOX (widgets->data));
 		values = g_object_get_data (G_OBJECT (combo_box),
@@ -472,36 +471,32 @@ eel_preferences_glade_list_enum_changed (GtkComboBox *combo_box,
 		}
 
 		if (values[i] != NULL) {
-			eel_string_list_insert (list, g_strdup (values[i]));
+			g_ptr_array_add (v, values[i]);
 		}
 	}
+	g_ptr_array_add (v, NULL);
 
-	eel_preferences_set_string_list (key, list);
-	eel_string_list_free (list);
+	eel_preferences_set_string_array (key, (char **) v->pdata);
+	g_ptr_array_free (v, TRUE);
 }
 
 static void
 eel_preferences_glade_list_enum_update (GtkWidget *widget)
 {
-	EelStringList *value_list;
-	int values;
+	char **values;
 	GSList *components;
 	int i;
-	char *item;
 
-	value_list = eel_preferences_get_string_list (g_object_get_data (G_OBJECT (widget),
-									 EEL_PREFERENCES_GLADE_DATA_KEY));
-	values = eel_string_list_get_length (value_list);
+	values = eel_preferences_get_string_array (g_object_get_data (G_OBJECT (widget),
+								      EEL_PREFERENCES_GLADE_DATA_KEY));
 	components = g_object_get_data (G_OBJECT (widget), EEL_PREFERENCES_GLADE_DATA_WIDGETS);
-	for (i = 0; i < values && components != NULL; i++, components = components->next) {
-		item = eel_string_list_nth (value_list, i);
+	for (i = 0; values[i] != NULL && components != NULL; i++, components = components->next) {
 		eel_preferences_glade_combo_box_update (GTK_COMBO_BOX (components->data), 
-							  item,
-							  G_CALLBACK (eel_preferences_glade_list_enum_changed));
-		g_free (item);
+							values[i],
+							G_CALLBACK (eel_preferences_glade_list_enum_changed));
 	}
 
-	eel_string_list_free (value_list);
+	g_strfreev (values);
 }
 
 void 
